pub struct KnativeEventingResources {
pub claims: Option<Vec<KnativeEventingResourcesClaims>>,
pub container: String,
pub limits: Option<BTreeMap<String, IntOrString>>,
pub requests: Option<BTreeMap<String, IntOrString>>,
}Expand description
ResourceRequirementsOverride enables the user to override any container’s resource requests/limits specified in the embedded manifest
Fields
claims: Option<Vec<KnativeEventingResourcesClaims>>Claims lists the names of resources, defined in spec.resourceClaims, that are used by this container.
This field depends on the DynamicResourceAllocation feature gate.
This field is immutable. It can only be set for containers.
container: StringThe container name
limits: Option<BTreeMap<String, IntOrString>>Limits describes the maximum amount of compute resources allowed. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
requests: Option<BTreeMap<String, IntOrString>>Requests describes the minimum amount of compute resources required. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. Requests cannot exceed Limits. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/